@@ -34,7 +34,7 @@ class Tistag(TestCase):
 
     if PY3:
         def test_py3(self):
-            self.failUnlessRaises(ValueError, istag, b"abc")
+            self.failUnlessRaises(TypeError, istag, b"abc")
 
 add(Tistag)
 
@@ -77,7 +77,7 @@ class TVComment(TestCase):
         self.failUnlessRaises(ValueError, self.c.write)
 
     def test_validate_nonunicode_value(self):
-        self.c.append(("uvalid", b"wt\xff"))
+        self.c.append((u"valid", b"wt\xff"))
         self.failUnlessRaises(ValueError, self.c.validate)
         self.failUnlessRaises(ValueError, self.c.write)
 
@@ -93,6 +93,13 @@ class TVComment(TestCase):
         self.failUnlessRaises(ValueError, self.c.validate)
         self.failUnlessRaises(ValueError, self.c.write)
 
+    def test_validate_utf8_value(self):
+        self.c.append((u"valid", b"\xc3\xbc\xc3\xb6\xc3\xa4"))
+        if PY3:
+            self.failUnlessRaises(ValueError, self.c.validate)
+        else:
+            self.c.validate()
+
     def test_invalid_format_strict(self):
         data = (b'\x07\x00\x00\x00Mutagen\x01\x00\x00\x00\x03\x00\x00'
                 b'\x00abc\x01')
@@ -186,6 +193,18 @@ class TVCommentDict(TestCase):
         self.c["woo"] = "bar"
         self.failUnlessEqual(self.c["woo"], ["bar"])
 
+    def test_slice(self):
+        l = [("foo", "bar"), ("foo", "bar2")]
+        self.c[:] = l
+        self.assertEqual(self.c[:], l)
+        self.failUnlessEqual(self.c["foo"], ["bar", "bar2"])
+        del self.c[:]
+        self.assertEqual(self.c[:], [])
+
+    def test_iter(self):
+        self.assertEqual(next(iter(self.c)), ("artist", "mu"))
+        self.assertEqual(list(self.c)[0], ("artist", "mu"))
+
     def test_del(self):
         del(self.c["title"])
         self.failUnlessRaises(KeyError, self.c.__getitem__, "title")
@@ -252,11 +271,11 @@ class TVCommentDict(TestCase):
 
     if PY3:
         def test_py3_bad_key(self):
-            self.failUnlessRaises(ValueError, self.c.get, b"a")
+            self.failUnlessRaises(TypeError, self.c.get, b"a")
             self.failUnlessRaises(
-                ValueError, self.c.__setitem__, b"a", "foo")
+                TypeError, self.c.__setitem__, b"a", "foo")
             self.failUnlessRaises(
-                ValueError, self.c.__delitem__, b"a")
+                TypeError, self.c.__delitem__, b"a")
 
     def test_duplicate_keys(self):
         self.c = VCommentDict()
